@@ -11,7 +11,7 @@ use Carp();
 use English qw( -no_match_vars );
 use DirHandle();
 
-our $VERSION = 0.04;
+our $VERSION = 0.05;
 
 sub _SIZE_OF_TZ_HEADER                     { return 44 }
 sub _SIZE_OF_TRANSITION_TIME_V1            { return 4 }
@@ -30,8 +30,6 @@ sub _SECONDS_IN_ONE_HOUR                   { return 3_600 }
 sub _SECONDS_IN_ONE_DAY                    { return 86_400 }
 sub _NEGATIVE_ONE                          { return -1 }
 sub _LOCALTIME_ISDST_INDEX                 { return 8 }
-sub _LOCALTIME_GMTOFF_INDEX                { return 9 }
-sub _LOCALTIME_TMZONE_INDEX                { return 10 }
 sub _LOCALTIME_DAY_OF_WEEK_INDEX           { return 6 }
 sub _LOCALTIME_YEAR_INDEX                  { return 5 }
 sub _LOCALTIME_MONTH_INDEX                 { return 4 }
@@ -63,7 +61,6 @@ sub _DAYS_IN_ONE_WEEK                      { return 7 }
 sub _EVERY_FOUR_HUNDRED_YEARS              { return 400 }
 sub _EVERY_FOUR_YEARS                      { return 4 }
 sub _EVERY_ONE_HUNDRED_YEARS               { return 100 }
-sub _BSD_NUMER_OF_ELEMENTS_IN_LOCALTIME    { return 10 }
 sub _DEFAULT_DST_START_HOUR                { return 2 }
 sub _DEFAULT_DST_END_HOUR                  { return 2 }
 
@@ -71,19 +68,11 @@ sub _TIMEZONE_FULL_NAME_REGEX {
     return qr/(?<area>\w+)(?:\/(?<location>[\w\-\/]+))?/smx;
 }
 
-my @_bsd_test_localtime = localtime;
-my $_bsd_localtime_extension =
-  ( ( scalar @_bsd_test_localtime ) == _BSD_NUMER_OF_ELEMENTS_IN_LOCALTIME() )
-  ? 1
-  : 0;
-
-sub _BSD_LOCALTIME_EXTENSION { return $_bsd_localtime_extension }
-
 my $_default_zoneinfo_directory = '/usr/share/zoneinfo';
-if ( -d $_default_zoneinfo_directory ) {
+if ( -e $_default_zoneinfo_directory ) {
 }
 else {
-    if ( -d '/usr/lib/zoneinfo' ) {
+    if ( -e '/usr/lib/zoneinfo' ) {
         $_default_zoneinfo_directory = '/usr/lib/zoneinfo';
     }
 }
@@ -931,10 +920,6 @@ sub local_time {
     if (wantarray) {
         my (@local_time) = $self->_gm_time($time);
         $local_time[ _LOCALTIME_ISDST_INDEX() ] = $isdst;
-        if ( _BSD_LOCALTIME_EXTENSION() ) {
-            $local_time[ _LOCALTIME_GMTOFF_INDEX() ] = $gmtoff;
-            $local_time[ _LOCALTIME_TMZONE_INDEX() ] = $abbr;
-        }
         return @local_time;
     }
     else {
@@ -1443,7 +1428,7 @@ Time::Zone::Olson - Provides an interface to the Olson timezone database
 
 =head1 VERSION
 
-Version 0.01
+Version 0.05
 
 =cut
 
@@ -1453,8 +1438,8 @@ Version 0.01
 
     my $time_zone = Time::Zone::Olson->new({ timezone => 'Australia/Melbourne' }); # set timezone at creation time
     my $now = $time_zone->time_local($seconds, $minutes, $hours, $day, $month, $year); # convert from Australia/Melbourne time
-    foreach my $area (Time::Zone::Olson->areas()) {
-        foreach my $location (Time::Zone::Olson->locations($area)) {
+    foreach my $area ($time_zone->areas()) {
+        foreach my $location ($time_zone->locations($area)) {
             $time_zone->timezone("$area/$location");
             print scalar $time_zone->local_time($now); # output time in $area/$location local time
             warn scalar localtime($now) . " log message for sysadmin"; # but log in system local time
@@ -1477,15 +1462,15 @@ Both of these parameters default to C<$ENV{TZ}> and C<$ENV{TZDIR}> respectively.
 
 =head2 areas
 
-Time::Zone::Olson->areas() will return a list of the areas (such as Asia, Australia, Africa, America, Europe) from the zone.tab file.  The areas will be sorted alphabetically.
+The areas() object method will return a list of the areas (such as Asia, Australia, Africa, America, Europe) from the zone.tab file.  The areas will be sorted alphabetically.
 
 =head2 locations
 
-Time::Zone::Olson->locations($area) will return a list of the locations (such as Melbourne, Perth, Hobart) for a specified area from the zone.tab file.  The locations will be sorted alphabetically.
+The locations($area) object method will return a list of the locations (such as Melbourne, Perth, Hobart) for a specified area from the zone.tab file.  The locations will be sorted alphabetically.
 
 =head2 comment
 
-Time::Zone::Olson->comment($timezone) will return the matching comment from the zone.tab file for the timezone parameter.  For example, if C<"Australia/Melbourne"> was passed as a parameter, the L</comment> function would return C<"Victoria">
+The comment($timezone) object method will return the matching comment from the zone.tab file for the timezone parameter.  For example, if C<"Australia/Melbourne"> was passed as a parameter, the L</comment> function would return C<"Victoria">
 
 =head2 directory
 
